#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-imports-plugin
version:              1.0.0.3
visibility:           public
id:                   hls-explicit-imports-plugin-1.0.0.3-CZgY9NG1Rrk5jSLZaQD9Ms
key:                  hls-explicit-imports-plugin-1.0.0.3-CZgY9NG1Rrk5jSLZaQD9Ms
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
category:             Development
abi:                  e7ce0e1fb57311836cd86991251e1b19
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/hls-explicit-imports-plugin-1.0.0.3

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/hls-explicit-imports-plugin-1.0.0.3

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/hls-explicit-imports-plugin-1.0.0.3

hs-libraries:
    HShls-explicit-imports-plugin-1.0.0.3-CZgY9NG1Rrk5jSLZaQD9Ms

depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    containers-0.6.4.1 deepseq-1.4.4.0 ghc-8.10.5
    ghc-api-compat-8.6-3TY3o2v9hFDBa7VjHV0kS9
    ghcide-1.4.0.1-5stW1V6MhVBGeCRHZSaIfO
    hls-graph-1.4.0.0-JjoNjgtseYI6EUnVL33EGm
    hls-plugin-api-1.1.0.2-6o7hY0E5YQuCD8G4Bf3t3o
    lsp-1.2.0.0-JYjHpvPu1SW4k7gGYBb5ES text-1.2.4.1
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

